ytree\.arbor\.frontends\.rockstar\.arbor\.RockstarArbor
=======================================================

.. currentmodule:: ytree.arbor.frontends.rockstar.arbor

.. autoclass:: RockstarArbor

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~RockstarArbor.__init__
      ~RockstarArbor.add_alias_field
      ~RockstarArbor.add_analysis_field
      ~RockstarArbor.add_derived_field
      ~RockstarArbor.is_grown
      ~RockstarArbor.is_setup
      ~RockstarArbor.save_arbor
      ~RockstarArbor.select_halos
      ~RockstarArbor.set_selector
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~RockstarArbor.arr
      ~RockstarArbor.box_size
      ~RockstarArbor.field_info
      ~RockstarArbor.hubble_constant
      ~RockstarArbor.quan
      ~RockstarArbor.size
      ~RockstarArbor.trees
      ~RockstarArbor.unit_registry
   
   